@@ -29,7 +29,7 @@ def load_dir(input_path, level):
         for class_dir in sorted(os.listdir(input_path)):
             if not os.path.isdir(f'{input_path}/{class_dir}'):
                 continue
-                
+
             for img_name in sorted(os.listdir(f"{input_path}/{class_dir}")):
                 img_path = f"{input_path}/{class_dir}/{img_name}"
                 content = {"idx": idx, "class": class_dir,
@@ -49,7 +49,17 @@ def handle_src(src, output_dir, rel_path=True):
     return src
 
 
-def generate_html_table(content_table, image_width='auto', image_height='auto', output_path='', float_precision=3, max_str_len=30, rel_path=True, save=True, title="Showdata"):
+def generate_html_table(content_table,
+                        image_width='auto',
+                        image_height='auto',
+                        output_path='',
+                        float_precision=3,
+                        max_str_len=30,
+                        rel_path=True,
+                        save=True,
+                        title="Showdata",
+                        head_div=None,
+                        page_size=10):
     """Generate html table
 
     Args:
@@ -61,6 +71,8 @@ def generate_html_table(content_table, image_width='auto', image_height='auto',
         max_str_len: Max string length.
         rel_path: Whether to use the relative path of input image and output path.
         save: Whether to save output file.
+        head_div: You can append some custom info in the top of the page.
+        page_size: default page size.
     """
     output_dir = os.path.split(output_path)[0]
     html = '<html>'
@@ -73,6 +85,7 @@ def generate_html_table(content_table, image_width='auto', image_height='auto',
         <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
         <meta http-equiv="Expires" content="0" />
         <meta http-equiv="X-UA-Compatible" content="IE=edge">
+        <link href="https://unpkg.com/jquery-resizable-columns@0.2.3/dist/jquery.resizableColumns.css" rel="stylesheet">
         <link href="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.5.3/css/bootstrap.min.css" rel="stylesheet">
         <link href="https://cdn.bootcdn.net/ajax/libs/font-awesome/5.15.1/css/all.min.css" rel="stylesheet">
         <link rel="stylesheet" href="https://unpkg.zhimg.com/bootstrap-table@1.18.0/dist/bootstrap-table.min.css">
@@ -81,7 +94,9 @@ def generate_html_table(content_table, image_width='auto', image_height='auto',
 
     html += '</head>'
     html += '<body>'
-    html += """
+    if head_div:
+        html += head_div
+    html += f"""
         <table
             class="table"
             id="table"
@@ -89,6 +104,7 @@ def generate_html_table(content_table, image_width='auto', image_height='auto',
             data-pagination="true"
             data-show-toggle="true"
             data-show-jump-to="true"
+            data-page-size="{page_size}"
             data-page-list="[10, 25, 50, 100, all]"
             data-show-refresh="true"
             data-show-fullscreen="true"
@@ -119,6 +135,7 @@ def generate_html_table(content_table, image_width='auto', image_height='auto',
     html += """
         <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.5.1/jquery.min.js" integrity="sha512-bLT0Qm9VnAYZDflyKcBaQ2gg0hSYNQrJ8RilYldYQ1FxQYoCLtUjuuRuZo+fjqhx/qtq/1itJ0C2ejDxltZVFg==" crossorigin="anonymous"></script>
         <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js" integrity="sha384-UO2eT0CpHqdSJQ6hJty5KVphtPhzWj9WO1clHTMGa3JDZwrnQq4sF86dIHNDz0W1" crossorigin="anonymous"></script>
+        <script src="https://unpkg.com/jquery-resizable-columns@0.2.3/dist/jquery.resizableColumns.min.js"></script>
         <script src="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.5.3/js/bootstrap.min.js"></script>
         <script src="https://unpkg.zhimg.com/bootstrap-table@1.18.0/dist/bootstrap-table.min.js"></script>
         <script src="https://unpkg.zhimg.com/bootstrap-table@1.18.0/dist/extensions/page-jump-to/bootstrap-table-page-jump-to.min.js"></script>
